@@ -90,7 +90,7 @@ validation_fn(potential_outcomes_handler) <- function(ret, dots, label) {
 
 
   ret <- build_step(
-    currydata(s3method, dots, strictDataParam = attr(ret, "strictDataParam")),
+    currydata(s3method, dots),
     handler = s3method,
     dots = dots,
     label = label,
@@ -198,10 +198,7 @@ validation_fn(potential_outcomes.formula) <- function(ret, dots, label) {
   dots$assignment_variables <- names(dots$conditions)
 
   ret <- build_step(currydata(potential_outcomes.formula,
-    dots,
-    strictDataParam = attr(ret, "strictDataParam"),
-    cloneDots = FALSE
-  ),
+    dots),
   handler = potential_outcomes.formula,
   dots = dots,
   label = label,
@@ -228,7 +225,7 @@ validation_fn(potential_outcomes.formula) <- function(ret, dots, label) {
 #
 #  Checks for unrevealed outcome variables.
 #
-#  If there are any, inject a declare_reveal step after the latest assign/reveal of an assn variable
+#  If there are any, inject a reveal_outcomes step after the latest assign/reveal of an assn variable
 #
 #
 pofdv <- function(design, i, step) {
@@ -274,14 +271,14 @@ pofdv <- function(design, i, step) {
   prev_unrevealed <- check("assignment_variables", "reveal", "outcome_variables", to = i - 1)
 
   if (length(prev_unassigned %i% prev_unrevealed) == 0) {
-    new_step <- eval_tidy(quo(declare_reveal(
+    new_step <- eval_tidy(quo(reveal_outcomes(
       outcome_variables = !!this_step_meta$outcome_variables,
       assignment_variables = !!this_step_meta$assignment_variables,
       label = !!paste("Autogenerated by", attr(step, "label"))
     )))
     attr(new_step, "auto-generated") <- TRUE
 
-    # warning("Attempting to inject a `declare_reveal(", this_step_meta$outcome_variables, ", ",
+    # warning("Attempting to inject a `reveal_outcomes(", this_step_meta$outcome_variables, ", ",
     #         this_step_meta$assignment_variables,
     #         ")` step after PO (", attr(step, "label"),
     #         ")", call. = FALSE)
@@ -296,7 +293,7 @@ pofdv <- function(design, i, step) {
   cant_find <- prev_unassigned %i% prev_unrevealed %i% unassigned_vars %i% unrevealed_vars
 
 
-  new_step <- eval_tidy(quo(declare_reveal(
+  new_step <- eval_tidy(quo(reveal_outcomes(
     outcome_variables = !!this_step_meta$outcome_variables,
     assignment_variables = !!this_step_meta$assignment_variables,
     label = !!paste("Autogenerated by", attr(step, "label"))
