@@ -19,7 +19,7 @@ test_that(
 
     my_mutate <- declare_step(dplyr::mutate, noise_sq = noise^2)
 
-    my_reveal <- declare_reveal()
+    my_reveal <- reveal_outcomes()
 
     design <- my_population +
       my_potential_outcomes +
@@ -46,7 +46,7 @@ test_that("No estimators / estimands", {
     declare_potential_outcomes(Y_Z_0 = noise, Y_Z_1 = noise + 1) +
     declare_sampling(n = 250) +
     declare_assignment(m = 25) +
-    declare_reveal()
+    reveal_outcomes()
 
   head(draw_data(design))
   des_obj <- run_design(design)
