@@ -8,7 +8,7 @@ test_that("expand_design works", {
     pate <- declare_estimand(mean(Y_Z_1 - Y_Z_0), label = "pate")
     pate_estimator <-
       declare_estimator(Y ~ Z, estimand = pate, label = "pate_hat")
-    reveal_outcomes <- declare_reveal()
+    reveal_outcomes <- reveal_outcomes()
     my_design <- my_population +
       my_potential_outcomes +
       pate +
@@ -68,7 +68,7 @@ test_that("vary works", {
     pate <- declare_estimand(mean(Y_Z_1 - Y_Z_0), label = "pate")
     pate_estimator <-
       declare_estimator(Y ~ Z, estimand = pate, label = "pate_hat")
-    reveal_outcomes <- declare_reveal()
+    reveal_outcomes <- reveal_outcomes()
     my_design <- my_population +
       my_potential_outcomes +
       pate +
@@ -119,7 +119,7 @@ test_that("power curve", {
     pate <- declare_estimand(mean(Y_Z_1 - Y_Z_0), label = "pate")
     pate_estimator <-
       declare_estimator(Y ~ Z, estimand = pate, label = "pate_hat")
-    reveal_outcomes <- declare_reveal()
+    reveal_outcomes <- reveal_outcomes()
     my_design <- my_population +
       my_potential_outcomes +
       pate +
