@@ -6,7 +6,7 @@ my_potential_outcomes <-
 my_assignment <- declare_assignment(m = 25)
 my_estimand <- declare_estimand(ATE = mean(Y_Z_1 - Y_Z_0))
 my_estimator <- declare_estimator(Y ~ Z, estimand = my_estimand)
-my_reveal <- declare_reveal()
+my_reveal <- reveal_outcomes()
 
 my_design_1 <- my_population + my_potential_outcomes + my_estimand + my_assignment + my_reveal + my_estimator
 
@@ -54,7 +54,7 @@ my_designer <- function(N, tau) {
   my_assignment <- declare_assignment(m = floor(N / 2))
   my_estimand <- declare_estimand(ATE = mean(Y_Z_1 - Y_Z_0))
   my_estimator <- declare_estimator(Y ~ Z, estimand = my_estimand)
-  my_reveal <- declare_reveal()
+  my_reveal <- reveal_outcomes()
   my_design_1 <- pop + pos + my_estimand + my_assignment + my_reveal + my_estimator
   my_design_1
 }
@@ -100,14 +100,14 @@ test_that("designs with some estimators that don't have p.values return the p.va
     declare_potential_outcomes(Y ~ .25 * Z + rnorm(N)) +
     declare_estimand(ATE = mean(Y_Z_1 - Y_Z_0)) +
     declare_assignment() +
-    declare_reveal(Y, Z) +
+    reveal_outcomes(Y, Z) +
     declare_estimator(Y ~ Z, estimand = "ATE", label = "blah") +
-    declare_estimator(handler = tidy_estimator(my_custom_estimator), estimand = "ATE")
+    declare_estimator(handler = label_estimator(my_custom_estimator), estimand = "ATE")
   
   expect_equivalent(names(simulate_design(des, sims = 1)), c("design_label", "sim_ID", "estimand_label", "estimand", "estimator_label", 
                                                         "term", "estimate", "std.error", "statistic", "p.value", "conf.low", 
                                                         "conf.high", "df", "outcome"))
   
-  expect_equal(nrow(get_diagnosands(diagnose_design(des, sims = 2, diagnosands = declare_diagnosands(select = power)))), 2)
+  expect_equal(nrow(get_diagnosands(diagnose_design(des, sims = 2, diagnosands = declare_diagnosands(power = mean(p.value <= 0.05))))), 2)
   
-})
\ No newline at end of file
+})
